import java.io.*;
import java.nio.charset.Charset;

/**
 * Aufrufbeispiel fuer Linux:
 *    java ConsoleEncoding
 * Aufrufbeispiel fuer Windows in Westeuropa:
 *    java -Dconsole.encoding=CP850 ConsoleEncoding
 * Aufrufbeispiel innerhalb Eclipse unter Windows:
 *    java -Dconsole.encoding=Cp1252 ConsoleEncoding
 */
public class ConsoleEncoding
{
   public static void main( String[] args ) throws IOException
   {
      // Sonderzeichen: &auml; &ouml; &uuml; &szlig; &sect; &euro; &frac12; &sup2; &radic; &sum;
      String sonderzeichen = ( args.length > 0 ) ? args[0] :
                             "\u00E4\u00F6\u00FC\u00DF\u00A7\u20AC\u00BD\u00B2\u221A\u2211";
      String osn  = System.getProperty( "os.name" );
      String fcp  = System.getProperty( "file.encoding" );
      String ccp  = System.getProperty( "console.encoding" );
      String ccps = ccp + " (uebergeben)";

      if( ccp == null ) {
         // Wir raten die Codepage der Konsole
         // (Cp850 ist nur fuer westeuropaeische Laender korrekt):
         ccp = ( osn != null && osn.contains( "Windows" ) ) ? "Cp850" : fcp;
         ccps = ccp + " (vermutet)";
      }

      System.out.println( "os.name:          " + osn );
      System.out.println( "default-charset:  " + Charset.defaultCharset() );
      System.out.println( "file.encoding:    " + fcp );
      System.out.println( "console.encoding: " + ccps );

      // Ausgabe mit Standard-System.out und unveraenderter Codepage:
      System.out.println( "Mit System.out:   " + sonderzeichen );

      // Ausgabe mit PrintWriter und gesetzter Konsolen-Codepage:
      PrintWriter pw = new PrintWriter( new OutputStreamWriter( System.out, ccp ) );
      pw.println( "Mit PrintWriter:  " + sonderzeichen );
      pw.flush();

      // System.out-Ausgabe mit neuem PrintStream mit gesetzter Konsolen-Codepage:
      System.setOut( new PrintStream( System.out, true, ccp ) );
      System.setErr( new PrintStream( System.err, true, ccp ) );
      System.out.println( "Mit PrintStream:  " + sonderzeichen );
   }
}
